@@ -16,8 +16,8 @@ extern SEXP fitCureModel(SEXP,SEXP,SEXP,SEXP,SEXP,SEXP);
 extern SEXP aft_model_output(SEXP);
 extern SEXP vunirootRcpp(SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP);
 extern SEXP multistate_ddt(SEXP,SEXP,SEXP,SEXP);
-extern SEXP runMarkovODE(SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP);
-extern SEXP runExpM(SEXP,SEXP,SEXP);
+// extern SEXP runMarkovODE(SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP);
+// extern SEXP runExpM(SEXP,SEXP,SEXP);
 extern SEXP plugin_P_by(SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP);
 extern SEXP plugin_P_L_by(SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP,SEXP);
 extern SEXP test_read_gsm(SEXP);
@@ -34,8 +34,8 @@ static const R_CallMethodDef CallEntries[] = {
     {"aft_model_output",   (DL_FUNC) &aft_model_output,   1},
     {"vunirootRcpp",       (DL_FUNC) &vunirootRcpp,       7},
     {"multistate_ddt",     (DL_FUNC) &multistate_ddt,     4},
-    {"runMarkovODE",       (DL_FUNC) &runMarkovODE,       9},
-    {"runExpM",            (DL_FUNC) &runExpM,            3},
+    // {"runMarkovODE",       (DL_FUNC) &runMarkovODE,       9},
+    // {"runExpM",            (DL_FUNC) &runExpM,            3},
     {"plugin_P_by",        (DL_FUNC) &plugin_P_by,        7},
     {"plugin_P_L_by",      (DL_FUNC) &plugin_P_L_by,     10},
     {"test_read_gsm",      (DL_FUNC) &test_read_gsm,      1},
